@@ -33,6 +33,24 @@ class CheckModulationsManager(surveil_manager.SurveilManager):
         )
         return body
 
+    def get(self, checkmodulation_name):
+        """Get a new checkmodulation."""
+        resp, body = self.http_client.json_request(
+            CheckModulationsManager.base_url + '/' +
+            checkmodulation_name, 'GET',
+            body=''
+        )
+        return body
+
+    def update(self, checkmodulation_name, checkmodulation):
+        """Update a checkmodulation."""
+        resp, body = self.http_client.json_request(
+            CheckModulationsManager.base_url + '/' +
+            checkmodulation_name, 'PUT',
+            body=checkmodulation
+        )
+        return body
+
     def delete(self, checkmodulation_name):
         """Delete a checkmodulation."""
         resp, body = self.http_client.request(
